@@ -842,6 +842,11 @@ class Askdata(SignUp):
 
     def save_dataset(self, df:pd.DataFrame, workspace: str, dataset_slug="", replace=False, dataset_name="", locale="en"):
 
+        df = df.where(pd.notnull(df), None)
+        for col in df.columns:
+            if (df[col].dtypes == "datetime64[ns]"):
+                df[col] = df[col].astype("str")
+
         if "/" in workspace:
             agentSlug = workspace.split("/")[0]
             datasetSlug = workspace.split("/")[1]
