@@ -66,6 +66,12 @@ class AskdataPandasExtension:
 
     def save_dataset(self, workspace:str, dataset_slug="", replace=False, dataset_name="", locale="en"):
 
+        self._df = self._df.where(pd.notnull(self._df), None)
+
+        for col in self._df.columns:
+            if (self._df[col].dtypes == "datetime64[ns]"):
+                self._df[col] = self._df[col].astype("str")
+                
         if self._env.lower() == 'dev':
             askdata_url = url_list['BASE_URL_ASKDATA_DEV']
         elif self._env.lower() == 'qa':
